@@ -4,9 +4,10 @@ import os
 import re
 import sys
 import yaml
+import inspect
 import argparse
 from enum import Enum
-from argparse import Namespace, Action, SUPPRESS, _StoreAction, _SubParsersAction
+from argparse import Namespace, Action, SUPPRESS, _StoreAction, _HelpAction, _SubParsersAction
 
 from .optionals import get_config_read_mode, FilesCompleterMethod
 from .typing import restricted_number_type
@@ -16,7 +17,9 @@ from .util import (
     ParserError,
     namespace_to_dict,
     dict_to_namespace,
+    import_object,
     Path,
+    _load_config,
     _flat_namespace_to_dict,
     _dict_to_flat_namespace,
     _check_unknown_kwargs,
@@ -69,6 +72,17 @@ def _is_action_value_list(action:Action):
     return False
 
 
+def _remove_actions(parser, types):
+
+    def remove(actions):
+        rm_actions = [a for a in actions if isinstance(a, types)]
+        for action in rm_actions:
+            actions.remove(action)
+
+    remove(parser._actions)
+    remove(parser._action_groups[1]._group_actions)
+
+
 class ActionConfigFile(Action, FilesCompleterMethod):
     """Action to indicate that an argument is a configuration file or a configuration string."""
 
@@ -103,32 +117,83 @@ class ActionConfigFile(Action, FilesCompleterMethod):
                 cfg_path = None
                 cfg_file = parser.parse_string(value, env=False, defaults=False, _skip_check=True)
             except (TypeError, yamlParserError, yamlScannerError) as ex_str:
-                raise TypeError('Parser key "'+dest+'": '+str(ex_str))
+                raise TypeError('Parser key "'+dest+'": '+str(ex_str)) from ex_str
         else:
             cfg_file = parser.parse_path(value, env=False, defaults=False, _skip_check=True)
         cfg_file = _dict_to_flat_namespace(namespace_to_dict(cfg_file))
         getattr(namespace, dest).append(cfg_path)
         for key, val in vars(cfg_file).items():
-            if key == '__cwd__' and hasattr(namespace, '__cwd__'):
-                setattr(namespace, key, getattr(namespace, key)+val)
-            else:
-                setattr(namespace, key, val)
+            setattr(namespace, key, val)
 
 
 class _ActionPrintConfig(Action):
     def __init__(self,
                  option_strings,
                  dest=SUPPRESS,
-                 default=SUPPRESS,
-                 help='print configuration and exit'):
+                 default=SUPPRESS):
         super().__init__(option_strings=option_strings,
                          dest=dest,
                          default=default,
-                         nargs=0,
-                         help=help)
+                         nargs='?',
+                         metavar='skip_null',
+                         help='Print configuration and exit.')
 
-    def __call__(self, parser, *args, **kwargs):
-        parser._print_config = True
+    def __call__(self, parser, namespace, value, option_string=None):
+        kwargs = {'skip_none': False}
+        if value is not None and 'skip_null' in value:
+            kwargs['skip_none'] = True
+        parser._print_config = kwargs
+
+
+class _ActionConfigLoad(Action):
+
+    def __init__(self, **kwargs):
+        kwargs['help'] = SUPPRESS
+        kwargs['default'] = SUPPRESS
+        super().__init__(**kwargs)
+
+    def __call__(self, parser, namespace, value, option_string=None):
+        cfg_file = self._load_config(value)
+        for key, val in vars(cfg_file).items():
+            setattr(namespace, self.dest+'.'+key, val)
+
+    def _load_config(self, value):
+        try:
+            return _load_config(value)
+        except (TypeError, yamlParserError, yamlScannerError) as ex:
+            raise TypeError('Parser key "'+self.dest+'": '+str(ex)) from ex
+
+    def _check_type(self, value, cfg=None):
+        return self._load_config(value)
+
+
+class _ActionHelpClassPath(Action):
+
+    def __init__(self, **kwargs):
+        if 'baseclass' in kwargs:
+            _check_unknown_kwargs(kwargs, {'baseclass'})
+            self._baseclass = kwargs['baseclass']
+        else:
+            self._baseclass = kwargs.pop('_baseclass')
+            kwargs['help'] = 'Show the help for the given class path and exit.'
+            kwargs['metavar'] = 'CLASS'
+            kwargs['default'] = SUPPRESS
+            super().__init__(**kwargs)
+
+    def __call__(self, *args, **kwargs):
+        if len(args) == 0:
+            kwargs['_baseclass'] = self._baseclass
+            return _ActionHelpClassPath(**kwargs)
+        val_class = import_object(args[2])
+        if not _issubclass(val_class, self._baseclass):
+            raise TypeError('Class "'+args[2]+'" is not a subclass of '+self._baseclass.__name__)
+        dest = re.sub('\\.help$', '',  self.dest) + '.init_args'
+        ArgumentParser = import_object('jsonargparse.ArgumentParser')
+        tmp = ArgumentParser()
+        tmp.add_class_arguments(val_class, dest)
+        _remove_actions(tmp, (_HelpAction, _ActionPrintConfig))
+        tmp.print_help()
+        args[0].exit()
 
 
 class ActionYesNo(Action):
@@ -341,7 +406,7 @@ class ActionParser(Action):
             if fpath is not None:
                 value.__path__ = fpath
         except KeyError as ex:
-            raise type(ex)(re.sub('^Parser key ([^:]+):', 'Parser key '+self.dest+'.\\1: ', str(ex)))
+            raise type(ex)(re.sub('^Parser key ([^:]+):', 'Parser key '+self.dest+'.\\1: ', str(ex))) from ex
         return value
 
     @staticmethod
@@ -393,14 +458,7 @@ class _ActionSubCommands(_SubParsersAction):
 
         parser.prog = '%s [options] %s' % (self._prog_prefix, name)
         parser.env_prefix = self._env_prefix+'_'+name+'_'
-
-        def remove_print_config(actions):
-            print_config = [a for a in actions if isinstance(a, _ActionPrintConfig)]
-            if len(print_config) > 0:
-                actions.remove(print_config[0])
-
-        remove_print_config(parser._actions)
-        remove_print_config(parser._action_groups[1]._group_actions)
+        _remove_actions(parser, _ActionPrintConfig)
 
         # create a pseudo-action to hold the choice help
         aliases = kwargs.pop('aliases', ())
@@ -535,7 +593,7 @@ class ActionPath(Action, FilesCompleterMethod):
                     val = Path(val, mode=self._mode, skip_check=self._skip_check)
                 value[num] = val
         except TypeError as ex:
-            raise TypeError('Parser key "'+self.dest+'": '+str(ex))
+            raise TypeError('Parser key "'+self.dest+'": '+str(ex)) from ex
         return value if islist else value[0]
 
 
@@ -598,7 +656,7 @@ class ActionPathList(Action, FilesCompleterMethod):
                     with sys.stdin if path_list_file == '-' else open(path_list_file, 'r') as f:
                         path_list = [x.strip() for x in f.readlines()]
                 except FileNotFoundError as ex:
-                    raise TypeError('Problems reading path list: '+path_list_file+' :: '+str(ex))
+                    raise TypeError('Problems reading path list: '+path_list_file+' :: '+str(ex)) from ex
                 cwd = os.getcwd()
                 if self._rel == 'list' and path_list_file != '-':
                     os.chdir(os.path.abspath(os.path.join(path_list_file, os.pardir)))
@@ -607,7 +665,7 @@ class ActionPathList(Action, FilesCompleterMethod):
                         try:
                             path_list[num] = Path(val, mode=self._mode)
                         except TypeError as ex:
-                            raise TypeError('Path number '+str(num+1)+' in list '+path_list_file+', '+str(ex))
+                            raise TypeError('Path number '+str(num+1)+' in list '+path_list_file+', '+str(ex)) from ex
                 finally:
                     os.chdir(cwd)
                 value += path_list
